#' 99335 ColipgeF-spec, famp, 2-step,pres(1) abs(2)/ 1 L
#'
#' A table containing the USGS ColipgeF-spec, famp, 2-step,pres(1) abs(2)/ 1 L
#' parameter codes.
#'
#' @format A data frame with 2 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_99335"
#> [1] "pmcode_99335"
